@@ -406,22 +406,25 @@ function reorganize_goals(grouping_policy) {
     // Replace table with grouped rows
     let toplevel = document.querySelector(":not(.rubric_row)>.rubric_table");
 
-    // Create replacement table
-    let replacement = document.createElement('div');
-    replacement.classList.add("rubric_table");
-
-    // Group things up
-    for (let i = 0; i < group_titles.length; ++i) {
-        replacement.innerHTML += (
-            "<h3 class='rubric_group_tile'>" + group_titles[i] + "</h3>"
-        );
-        for (let row of groups[i]) {
-            replacement.innerHTML += row.outerHTML;
+    // Only replace if we found a table
+    if (toplevel) {
+        // Create replacement table
+        let replacement = document.createElement('div');
+        replacement.classList.add("rubric_table");
+       
+        // Group things up
+        for (let i = 0; i < group_titles.length; ++i) {
+            replacement.innerHTML += (
+                "<h3 class='rubric_group_tile'>" + group_titles[i] + "</h3>"
+            );
+            for (let row of groups[i]) {
+                replacement.innerHTML += row.outerHTML;
+            }
         }
+       
+        // Swap out content
+        toplevel.innerHTML = replacement.innerHTML;
     }
-
-    // Swap out content
-    toplevel.innerHTML = replacement.innerHTML;
 }
 
 // Reorganize goals on load + on selector change if there is one
