@@ -113,14 +113,14 @@ from potluck import meta # noqa E402
 
 meta.example("imperfect")
 
-meta.expect("partial", "procedure", "core", "readNums")
+meta.expect("partial", "define readNums")
 meta.expect("failed", "#core.check:def-readNums:with:loop:try")
 
-meta.expect("failed", "product", "core", "grep")
-meta.expect("partial", "product", "core", "readNums")
+meta.expect("failed", "grep must")
+meta.expect("partial", "readNums must")
 
-meta.expect("failed", "behavior", "core", "listFile")
-meta.expect("failed", "behavior", "extra", "addRecords")
+meta.expect("failed", "listFile must")
+meta.expect("failed", "addRecords must")
 
 
 # Snippets
