@@ -15,8 +15,8 @@ from potluck import meta # noqa E402
 
 meta.example("imperfect")
 
-meta.expect("failed", "product", "core", "var2")
-meta.expect("failed", "product", "core", "var3")
+meta.expect("failed", "var2")
+meta.expect("failed", "var3")
 
 # var4 should succeed despite structural differences
 
