@@ -536,7 +536,10 @@ def check_tests_harness(
     pass, even if more than the required number of tests are defined,
     otherwise enough tests must pass (i.e., have been checked at least
     once and have succeeded on every check applied) to meet the minimum
-    requirements, but cases beyond those are allowed to fail.
+    requirements, but cases beyond those are allowed to fail. If
+    `_must_pass` is set to the string "not all" then at least one test
+    must fail, but the specific number of successes/failures is not
+    reported.
 
     Note that this function has a side effect of deleting all
     previously-defined optimism tests.
@@ -580,7 +583,7 @@ def check_tests_harness(
 
     # List all currently defined test cases (i.e., those defined by the
     # function we're looking at)
-    defined = optimism.listAllCases()
+    defined = optimism.listAllTrials()
 
     report = ""
 
@@ -693,8 +696,8 @@ def check_tests_harness(
                     only = "Only " if succeeded > 0 else ""
                     out_of = f"/{total}" if total > succeeded else ""
                     report += (
-                        f"{only}{succeeded}{out_of} {cases_passed} for test(s)"
-                        f" of {show_case_id} ({threshold} were"
+                        f"{only}{succeeded}{out_of} {cases_passed} for"
+                        f" test(s) of {show_case_id} ({threshold} were"
                         f" required)\n"
                     )
             else:
